@@ -25,8 +25,6 @@
 #define kErrNoREST (-2000)
 #define kErrPrematureEOF (-2001)
 
-extern int SetStartOffset(const FTPCIPtr, longest_int);
-
 static int
 FTPGetBytes(
 	const FTPCIPtr cip,
@@ -317,11 +315,11 @@ FTPGetBytes(
 
 	if ((startPoint != (longest_int) 0) && (cip->hasREST == kCommandAvailabilityUnknown)) {
 		(void) FTPSetTransferType(cip, kTypeBinary);
-		if (SetStartOffset(cip, (longest_int) 1) == kNoErr) {
+		if (FTPSetStartOffset(cip, (longest_int) 1) == kNoErr) {
 			/* Now revert -- we still may not end up
 			 * doing it.
 			 */
-			SetStartOffset(cip, (longest_int) -1);
+			FTPSetStartOffset(cip, (longest_int) -1);
 		} else {
 			return kErrNoREST;
 		}
