@@ -12,7 +12,7 @@
 #include <Strn.h>				/* Library header. */
 #include <sio.h>				/* Library header. */
 
-#if defined(WIN32) || defined(_WINDOWS)
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 #	define sleep WinSleep
 #endif
 
@@ -155,7 +155,7 @@ GetPass2(const char *const prompt)
 	static char pwbuf[128];
 
 	(void) memset(pwbuf, 0, sizeof(pwbuf));
-#if defined(WIN32) || defined(_WINDOWS)
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	if (! _isatty(_fileno(stdout)))
 		return (pwbuf);
 #else
@@ -196,26 +196,6 @@ Rp(int a)
 
 
 
-
-static double
-Duration(struct timeval *t0)
-{
-	struct timeval t1;
-	double sec;
-
-	gettimeofday(&t1, NULL);
-	if (t0->tv_usec > t1.tv_usec) {
-		t1.tv_usec += 1000000;
-		t1.tv_sec--;
-	}
-	sec = ((double) (t1.tv_usec - t0->tv_usec) * 0.000001)
-		+ (t1.tv_sec - t0->tv_sec);
-
-	return (sec);
-}	/* Duration */
-
-
-
 /*VARARGS*/
 static void
 MsgStart(const char *const fmt, ...)
@@ -1126,8 +1106,12 @@ main(int argc, char **argv)
 	STRNCPY(gPasswd, fi.pass);
 
 	if (seed < 0) {
+#if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
+		seed = ((unsigned int) time(NULL)) & 0xffff;
+#else
 		seed = (time(NULL) & 0xff) << 8;
 		seed |= (getpid() & 0xff);
+#endif
 	}
 	srand((unsigned int) seed);
 	gSeed = seed;
