@@ -447,6 +447,7 @@ Usage(void)
   catalog-file=/home/gleason/files/catalog.file\n");
 	(void) fprintf(fp, "\n\
 Other config file options:\n\
+  debug-log                (same as \"-d\"; default is off)\n\
   passive                  (yes/no, default: no)\n\
   sync-deletes             (yes/no, default: yes)\n\
   port                     (default: 21)\n\
@@ -772,6 +773,30 @@ StrToBool(const char *const s)
 
 
 
+static void
+SetDebugLog(const char *const fn)
+{
+	if ((gConn.debugLog != NULL) && (gConn.debugLog != stderr) && (gConn.debugLog != stdout)) {
+		(void) fclose(gConn.debugLog);
+	}
+	if (strcmp(fn, "stdout") == 0)
+		gConn.debugLog = stdout;
+	else if (fn[0] == '-')
+		gConn.debugLog = stdout;
+	else if (strcmp(fn, "stderr") == 0)
+		gConn.debugLog = stderr;
+	else
+		gConn.debugLog = fopen(
+			fn,
+#ifdef WIN32
+			"wt"
+#else
+			"w"
+#endif
+		);
+}	/* SetDebugLog */
+
+
 
 static void
 ReadSyncputConfigFile(const char *fn, FTPCIPtr cip)
@@ -856,6 +881,8 @@ ReadSyncputConfigFile(const char *fn, FTPCIPtr cip)
 				cip->dataPortMode = kPassiveMode;
 			else
 				cip->dataPortMode = kSendPortMode;
+		} else if (strncmp(tokstart, "debug-log", 9) == 0) {
+			SetDebugLog(tokstart + 10);
 		}
 	}
 	(void) fclose(fp);
@@ -924,14 +951,7 @@ main(int argc, char **argv)
 				gConn.errLog = fopen(opt.arg, "a");
 			break;
 		case 'd':
-			if (strcmp(opt.arg, "stdout") == 0)
-				gConn.debugLog = stdout;
-			else if (opt.arg[0] == '-')
-				gConn.debugLog = stdout;
-			else if (strcmp(opt.arg, "stderr") == 0)
-				gConn.debugLog = stderr;
-			else
-				gConn.debugLog = fopen(opt.arg, "w");
+			SetDebugLog(opt.arg);
 			break;
 		case 't':
 			SetTimeouts(&gConn, opt.arg);
